@@ -1,3 +1,5 @@
+# $Id: _Common.pm 85 2009-12-10 19:00:14Z cfaerber $
+
 package Unicode::Stringprep::_Common;
 
 use strict;
@@ -53,11 +55,11 @@ Unicode::Stringprep::_Common - Internal functions for C<Unicode::Stringprep::*>
 
 =head1 AUTHOR
 
-Claus FE<auml>rber E<lt>CFAERBER@cpan.orgE<gt>
+Claus Färber E<lt>CFAERBER@cpan.orgE<gt>
  
 =head1 LICENSE
  
-Copyright 2007-2009 Claus FE<auml>rber. All rights reserved.
+Copyright © 2007-2008 Claus Färber. All rights reserved.
  
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
